Prolog
======

Django-verification-token is a library which extends django with model and manager for generation verification tokens which can be used for user verification wia SMS or e-mail.

Installation
------------

.. code:: bash

    pip install django-verification-token


Docs
----

For more details see [docs](http://django-verification-token.readthedocs.org/)
